@@ -86,7 +86,7 @@
 #define KITEMVIEWS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMVIEWS_NO_DEPRECATED
-#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
+#  define KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef KITEMVIEWS_NO_DEPRECATED_WARNINGS
 #  define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE KITEMVIEWS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x54800
+#    define KITEMVIEWS_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
